@@ -25,8 +25,8 @@ from . import __version__
 from .errors import UnsupportedPythonVersion
 from .Search import Search, fSearch
 
-if not (sys.version_info.major >= 3 and sys.version_info.minor >= 8):
-    raise UnsupportedPythonVersion("This version of python is not supported (for now).")
+# if not (sys.version_info.major >= 3 and sys.version_info.minor >= 8):
+#     raise UnsupportedPythonVersion("This version of python is not supported (for now).")
 
 
 parser = argparse.ArgumentParser(
@@ -47,7 +47,7 @@ parser.add_argument(  # Query
     "query",
     help="The query to search.",
     nargs="*",
-    action="extend",
+    #     action="append",
 )
 parser.add_argument(  # JSON
     "-j",
